%%
%% This is file `litenc.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% oinuit.dtx  (with options: `LITenc')
%% 
%%  (c) copyright 2002 Apostolos Syropoulos
%%  This program can be redistributed and/or modified under the terms
%%  of the LaTeX Project Public License Distributed from CTAN
%%  archives in directory macros/latex/base/lppl.txt; either
%%  version 1 of the License, or any later version.
%%  use or alter this file in any way.
%% 
%%  Please report errors or suggestions for improvement to
%% 
%%     Apostolos Syropoulos
%%     366, 28th October Str.
%%     GR-671 00 Xanthi, GREECE
%%     apostolo@ocean1.ee.duth.gr or apostolo@obelix.ee.duth.gr
%% 
%% \CharacterTable
%%  {Upper-case    \A\B\C\D\E\F\G\H\I\J\K\L\M\N\O\P\Q\R\S\T\U\V\W\X\Y\Z
%%   Lower-case    \a\b\c\d\e\f\g\h\i\j\k\l\m\n\o\p\q\r\s\t\u\v\w\x\y\z
%%   Digits        \0\1\2\3\4\5\6\7\8\9
%%   Exclamation   \!     Double quote  \"     Hash (number) \#
%%   Dollar        \$     Percent       \%     Ampersand     \&
%%   Acute accent  \'     Left paren    \(     Right paren   \)
%%   Asterisk      \*     Plus          \+     Comma         \,
%%   Minus         \-     Point         \.     Solidus       \/
%%   Colon         \:     Semicolon     \;     Less than     \<
%%   Equals        \=     Greater than  \>     Question mark \?
%%   Commercial at \@     Left bracket  \[     Backslash     \\
%%   Right bracket \]     Circumflex    \^     Underscore    \_
%%   Grave accent  \`     Left brace    \{     Vertical bar  \|
%%   Right brace   \}     Tilde         \~}
\ProvidesFile{litenc.def}
[2002/07/21 v1.0 Local Inuktitut Encoding]
\DeclareFontEncoding{LIT}{}{}
\DeclareFontSubstitution{LIT}{cmr}{m}{n}
\DeclareErrorFont{LIT}{cmr}{m}{n}{10}
\endinput
%%
%% End of file `litenc.def'.
